//*****************************************************************************
// File Name	: 'lcd_lib_STC.h'
// Title		: Library Header File for ST7036 COntroller
// Author		: Sahil Potnis, Cornell University 
// Created		: 11-14-14
// Version		: 1.0
// Target MCU	: Atmel AVR series
// Operational Mode : 5V 4 Bit interface for AVR-GCC and EZ DOGM163W-A LCD
//*****************************************************************************
#ifndef LCD_LIB_STC
#define LCD_LIB_STC
#define LCD_PORT	PORTC				//datapins are PC0 to PC3 (DB4 to DB7 on the DOG)
#define PIN_ENABLE 	PC6             	// Enable on PINC.6
#define PIN_RS 		PC7             	//Regiter Select on PINC.7
#define PIN_RW      PC5             	//Read Write on PINC.5 
#define CHARACTER_BUFFER_BASE_ADDRESS		0b10000000
#define CHARACTERS_PER_ROW 							16	

//ST7036 Instruction Set
#define INSTRUCTION_CLEAR_DISPLAY    		0b00000001
#define INSTRUCTION_FUNCTION_SET_INIT_0  	0b00110011
#define INSTRUCTION_FUNCTION_SET_INIT_1  	0b00110010
#define INSTRUCTION_FUNCTION_SET_INIT_2  	0b00101001
#define INSTRUCTION_INSTRUCTION_SET_0    	0b00101000
#define INSTRUCTION_INSTRUCTION_SET_1 		0b00101001
#define INSTRUCTION_BIAS_SET				0b00010101
#define INSTRUCTION_POWER_CONTROL 			0b01010011
#define INSTRUCTION_FOLLOWER_CONTROL		0b01101100
#define INSTRUCTION_CONTRAST_SET			0b01111111
#define INSTRUCTION_DISPLAY_ON				0b00001100
#define INSTRUCTION_ENTRY_MODE 				0b00000110
#define INSTRUCTION_CURSOR_ON               0b00001110
#define INSTRUCTION_CURSOR_OFF              0b00001100
#define INSTRUCTION_CURSOR_RIGHT            0b00010100
#define INSTRUCTION_CURSOR_LEFT             0b00010000
#define INSTRUCTION_CURSOR_BLINK            0b00001111

#include <avr/io.h>
#include <util/delay.h>
#include <inttypes.h>

///******************FUNCTION DEFINITIONS*************************************** 
void write(char data);
void write_instruction(char instruction);
void write_data(char data);
void set_cursor(char row, char column);
void write_string(char* string);
void initialize_display();
void LCD_clr(void);
void LCDcursor_ON(void);
void LCDcursor_OFF(void);
void LCDcursor_blink(void);
void LCDcursor_Left(uint8_t);
void LCDcursor_Right(uint8_t);
void LCD_string(uint8_t*, uint8_t);
void CopyStringto_LCD(const uint8_t*, uint8_t, uint8_t);
//******************************************************************************

#endif


